# Changelog

## [V0.0.7a11](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a11) (2024-08-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a10...V0.0.7a11)

**Fixed bugs:**

- Playlists don't work when progressing naturally, but skips are fine [\#123](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/123)
- logs/end\_of\_track [\#124](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/124) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a10](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a10) (2024-08-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a9...V0.0.7a10)

**Fixed bugs:**

- fix/playlist\_handling [\#122](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/122) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a9](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a9) (2024-07-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a8...V0.0.7a9)

**Fixed bugs:**

- fix/play\_from\_gui [\#121](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/121) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a8) (2024-06-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a7...V0.0.7a8)

**Fixed bugs:**

- fix/native\_sources [\#120](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/120) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a7) (2024-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a6...V0.0.7a7)

**Merged pull requests:**

- default to OCP pipeline + support for utils 0.0.38 [\#119](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/119) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a6) (2024-05-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a5...V0.0.7a6)

**Fixed bugs:**

- fix/playlist\_again [\#117](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/117) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a5) (2024-05-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a4...V0.0.7a5)

**Fixed bugs:**

- fix playlist handling [\#116](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/116) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a4) (2024-05-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a3...V0.0.7a4)

**Fixed bugs:**

- fix/coexistence\_with\_pipeline [\#115](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/115) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a3) (2024-05-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a2...V0.0.7a3)

**Implemented enhancements:**

- feat/experimental\_ocp\_pipeline [\#112](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/112) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a2) (2024-01-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.7a1...V0.0.7a2)

**Merged pull requests:**

- refactor/dry\_ocp\_imports [\#109](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/109) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.7a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.7a1) (2024-01-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6...V0.0.7a1)

**Merged pull requests:**

- refactor/utils\_0.1.0 [\#108](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/108) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6) (2024-01-23)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a16...V0.0.6)

## [V0.0.6a16](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a16) (2024-01-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a15...V0.0.6a16)

**Fixed bugs:**

- OCP GUI stays up until dismissed after playing a single track [\#98](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/98)
- settings storage seems to be ambiguous [\#43](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/43)

**Merged pull requests:**

- Add upper version pin for ovos-utils [\#106](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/106) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a15](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a15) (2024-01-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a14...V0.0.6a15)

**Closed issues:**

- `StreamHandler` initialized on import [\#54](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/54)
- Emit messagebus event on Intent match [\#20](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/20)

**Merged pull requests:**

- Update news.intent [\#83](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/83) ([timonvanhasselt](https://github.com/timonvanhasselt))

## [V0.0.6a14](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a14) (2024-01-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a13...V0.0.6a14)

**Merged pull requests:**

- allow alpha utils [\#105](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/105) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a13](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a13) (2024-01-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a12...V0.0.6a13)

**Merged pull requests:**

- Update dependencies to stable versions with ovos-core 0.0.7 compat. [\#104](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/104) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a12](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a12) (2023-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a11...V0.0.6a12)

**Fixed bugs:**

- fix/OCP\_plugins\_loading [\#103](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/103) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a11](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a11) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a10...V0.0.6a11)

**Merged pull requests:**

- Update requirements.txt [\#102](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/102) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a10](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a10) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a9...V0.0.6a10)

**Merged pull requests:**

- bump requirements [\#101](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/101) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a9](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a9) (2023-10-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a8...V0.0.6a9)

**Merged pull requests:**

- Update requirements to stable versions [\#100](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/100) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a8) (2023-09-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a7...V0.0.6a8)

**Implemented enhancements:**

- Add standalone launcher [\#97](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/97) ([Ramblurr](https://github.com/Ramblurr))

## [V0.0.6a7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a7) (2023-08-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a6...V0.0.6a7)

**Merged pull requests:**

- OCPQuery: Only check if the gui is connected once [\#96](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/96) ([Ramblurr](https://github.com/Ramblurr))

## [V0.0.6a6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a6) (2023-08-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a5...V0.0.6a6)

**Fixed bugs:**

- Allow `PlaybackType.SKILL` search results to be played when there is no GUI [\#95](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/95) ([Ramblurr](https://github.com/Ramblurr))

**Closed issues:**

- OCP search results are not processed fast enough because `is_gui_connected(..)` takes too long [\#93](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/93)
- OCP skills supporting PlaybackType.SKILL cannot be played when there is no GUI [\#92](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/92)

**Merged pull requests:**

- Handle race condition between `ovos.common_play.query.response` and `ovos.common_play.skill.search_end` [\#94](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/94) ([Ramblurr](https://github.com/Ramblurr))

## [V0.0.6a5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a5) (2023-07-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a4...V0.0.6a5)

**Merged pull requests:**

- Update GUI to pass resource names instead of paths [\#90](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/90) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a4) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a3...V0.0.6a4)

**Fixed bugs:**

- fix/support for ui directories param [\#87](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/87) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a3) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a2...V0.0.6a3)

**Merged pull requests:**

- Update requirements.txt [\#86](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/86) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a2) (2023-06-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.6a1...V0.0.6a2)

**Closed issues:**

- All media play requests loop \(silently\) until ovos restart [\#84](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/84)
- self.active\_backend is undefined when fallback is triggered [\#82](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/82)

**Merged pull requests:**

- Refactor init to resolve deprecation warnings [\#85](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/85) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.6a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.6a1) (2023-04-23)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5...V0.0.6a1)

**Implemented enhancements:**

- Replace mycroft\_bus\_client with ovos\_bus\_client [\#80](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/80) ([goldyfruit](https://github.com/goldyfruit))

**Merged pull requests:**

- Fix automation typos [\#77](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/77) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a7...V0.0.5)

## [V0.0.5a7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a7) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a6...V0.0.5a7)

**Merged pull requests:**

- Update Automations and Dependencies [\#76](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/76) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.5a6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a6) (2023-04-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a5...V0.0.5a6)

**Fixed bugs:**

- Continue playback on track end [\#66](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/66)
- Paused Playback resumed on WW [\#22](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/22)

**Merged pull requests:**

- mycroft-bus-client -\> ovos-bus-client [\#72](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/72) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.5a5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a5) (2023-04-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a4...V0.0.5a5)

**Fixed bugs:**

- Bugfixes and Unit Tests [\#69](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/69) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.5a4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a4) (2023-04-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a3...V0.0.5a4)

**Closed issues:**

- \[BUG\] No clear way of exiting the music application [\#55](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/55)

## [V0.0.5a3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a3) (2023-04-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a2...V0.0.5a3)

**Merged pull requests:**

- Add exit button, simplfy buttons management and stop button [\#68](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/68) ([AIIX](https://github.com/AIIX))

## [V0.0.5a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a2) (2023-03-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.5a1...V0.0.5a2)

**Merged pull requests:**

- fix OCPQuery playlist [\#63](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/63) ([emphasize](https://github.com/emphasize))

## [V0.0.5a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.5a1) (2023-03-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4...V0.0.5a1)

**Merged pull requests:**

- Dutch \(nl-nl\) translations [\#59](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/59) ([timonvanhasselt](https://github.com/timonvanhasselt))

## [V0.0.4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4) (2023-03-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a14...V0.0.4)

## [V0.0.4a14](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a14) (2023-03-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a13...V0.0.4a14)

**Merged pull requests:**

- Update ovos-utils to stable version [\#61](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/61) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.4a13](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a13) (2023-03-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a12...V0.0.4a13)

**Merged pull requests:**

- Refactor utils.ocp\_plugins to a module property to init on reference instead of on import [\#56](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/56) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.4a12](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a12) (2023-03-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a11...V0.0.4a12)

**Merged pull requests:**

- fix skill featured list not showing on first boot [\#53](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/53) ([AIIX](https://github.com/AIIX))

## [V0.0.4a11](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a11) (2023-02-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a10...V0.0.4a11)

**Closed issues:**

- Add all plugins to optional dependencies [\#50](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/50)

**Merged pull requests:**

- fix removal of old title/author on new source title/author fail [\#52](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/52) ([AIIX](https://github.com/AIIX))

## [V0.0.4a10](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a10) (2023-02-23)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a9...V0.0.4a10)

**Merged pull requests:**

- Update OCP Plugin dependencies [\#51](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/51) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.4a9](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a9) (2023-02-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a8...V0.0.4a9)

**Implemented enhancements:**

- translations [\#48](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/48) ([emphasize](https://github.com/emphasize))

## [V0.0.4a8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a8) (2023-02-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a7...V0.0.4a8)

**Merged pull requests:**

- Added italian translation [\#49](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/49) ([denics](https://github.com/denics))

## [V0.0.4a7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a7) (2023-02-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a6...V0.0.4a7)

## [V0.0.4a6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a6) (2023-02-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a5...V0.0.4a6)

**Implemented enhancements:**

- feat/add\_plugin\_logs [\#46](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/46) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.4a5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a5) (2023-02-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a4...V0.0.4a5)

**Fixed bugs:**

- fix/extractor\_error [\#45](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/45) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.4a4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a4) (2023-02-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a3...V0.0.4a4)

**Merged pull requests:**

- fix requirement [\#44](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/44) ([emphasize](https://github.com/emphasize))

## [V0.0.4a3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a3) (2023-01-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a2...V0.0.4a3)

**Merged pull requests:**

- Revert sei change and add docstring with explanation [\#42](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/42) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.4a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a2) (2023-01-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.4a1...V0.0.4a2)

**Merged pull requests:**

- Add missing ':' in extractor SEI parsing [\#41](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/41) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.4a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.4a1) (2023-01-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3...V0.0.4a1)

## [V0.0.3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3) (2023-01-26)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a17...V0.0.3)

## [V0.0.3a17](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a17) (2023-01-26)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a16...V0.0.3a17)

**Merged pull requests:**

- Update dependencies to stable releases [\#40](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/40) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.3a16](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a16) (2023-01-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a15...V0.0.3a16)

**Merged pull requests:**

- Fix missed dbus settings reference [\#39](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/39) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.3a15](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a15) (2023-01-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a14...V0.0.3a15)

**Merged pull requests:**

- Add optional support for QtAV video player via configuration [\#34](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/34) ([AIIX](https://github.com/AIIX))

## [V0.0.3a14](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a14) (2023-01-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a13...V0.0.3a14)

**Merged pull requests:**

- Fix missed settings reference from workshop refactor [\#38](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/38) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.3a13](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a13) (2023-01-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a12...V0.0.3a13)

**Merged pull requests:**

- Update license tests to maintained GH Action [\#37](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/37) ([NeonDaniel](https://github.com/NeonDaniel))
- refactor/ovos workshop settings + deprecate OCPSettings [\#36](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/36) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.3a12](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a12) (2023-01-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a11...V0.0.3a12)

**Fixed bugs:**

- fix/uri\_None [\#35](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/35) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.3a11](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a11) (2023-01-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a10...V0.0.3a11)

## [V0.0.3a10](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a10) (2023-01-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a9...V0.0.3a10)

**Implemented enhancements:**

- Feat/ocp stream plugins [\#27](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/27) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.3a9](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a9) (2023-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a8...V0.0.3a9)

**Fixed bugs:**

- fix/metadata\_xtract [\#31](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/31) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.3a8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a8) (2023-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a7...V0.0.3a8)

**Merged pull requests:**

- Prevent duplicate messagebus events [\#32](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/32) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.3a7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a7) (2023-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a6...V0.0.3a7)

**Merged pull requests:**

- set video bg to black always [\#33](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/33) ([AIIX](https://github.com/AIIX))

## [V0.0.3a6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a6) (2022-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a5...V0.0.3a6)

**Merged pull requests:**

- Added debug logging, intent registration fixes [\#28](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/28) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.3a5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a5) (2022-12-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a4...V0.0.3a5)

**Merged pull requests:**

- Add application view timeout configuration option and handling [\#26](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/26) ([AIIX](https://github.com/AIIX))

## [V0.0.3a4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a4) (2022-11-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a3...V0.0.3a4)

**Merged pull requests:**

- fix button color issue [\#25](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/25) ([AIIX](https://github.com/AIIX))

## [V0.0.3a3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a3) (2022-09-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a2...V0.0.3a3)

**Merged pull requests:**

- wait for player to show before play is actually sent [\#24](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/24) ([AIIX](https://github.com/AIIX))

## [V0.0.3a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a2) (2022-09-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.3a1...V0.0.3a2)

**Implemented enhancements:**

- Refactor GUI Usage and Interface Changes [\#23](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/23) ([AIIX](https://github.com/AIIX))

## [V0.0.3a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.3a1) (2022-08-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2...V0.0.3a1)

**Fixed bugs:**

- fix/featured\_skills [\#19](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/19) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2) (2022-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a9...V0.0.2)

## [V0.0.2a9](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a9) (2022-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a8...V0.0.2a9)

**Merged pull requests:**

- Follow system theme [\#17](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/17) ([AIIX](https://github.com/AIIX))

## [V0.0.2a8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a8) (2022-08-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a7...V0.0.2a8)

**Implemented enhancements:**

- feat/native\_ocp [\#16](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/16) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.2a7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a7) (2022-08-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a6...V0.0.2a7)

**Implemented enhancements:**

- feat/plugin configs [\#15](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/15) ([NeonJarbas](https://github.com/NeonJarbas))

**Merged pull requests:**

- ocp / cps conflict tests [\#14](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/14) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.2a6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a6) (2022-06-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a5...V0.0.2a6)

**Merged pull requests:**

- Update minimum required ovos\_workshop version [\#13](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/13) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.2a5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a5) (2022-06-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a4...V0.0.2a5)

## [V0.0.2a4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a4) (2022-05-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a3...V0.0.2a4)

**Implemented enhancements:**

- Improve live invidious [\#12](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/12) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.2a3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a3) (2022-05-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a2...V0.0.2a3)

**Fixed bugs:**

- Fix/stream xtract/yt channel live [\#11](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/11) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.2a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a2) (2022-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.2a1...V0.0.2a2)

**Implemented enhancements:**

- Improve invidious [\#10](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/10) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.2a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.2a1) (2022-04-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.1...V0.0.2a1)

**Merged pull requests:**

- fix/ydl\_backend [\#9](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/9) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.1) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V0.0.1a2...V0.0.1)

## [V0.0.1a2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V0.0.1a2) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/f6b0dc8082672f6c5f092be7ffe2d0f4b0520882...V0.0.1a2)

**Implemented enhancements:**

- Add Audio Wave Visualization [\#5](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/5) ([AIIX](https://github.com/AIIX))
- Add basic gui page keynav support to webplayer and fullscreen mode [\#4](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/4) ([AIIX](https://github.com/AIIX))
- Add missing german intents [\#2](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/2) ([Y0ngg4n](https://github.com/Y0ngg4n))
- add keynav and qml for bigscreen [\#1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/1) ([AIIX](https://github.com/AIIX))

**Fixed bugs:**

- use mycroft icon units instead of kirigami [\#3](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/3) ([AIIX](https://github.com/AIIX))

**Closed issues:**

- GPL dependency [\#6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/issues/6)

**Merged pull requests:**

- feat/workflows [\#8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/8) ([JarbasAl](https://github.com/JarbasAl))
- feat/pypi\_automation [\#7](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/7) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
